# Generated by roxygen2: do not edit by hand

S3method(plot,gofmalm)
S3method(print,gofmalm)
S3method(summary,gofmalm)
export(fit_mle)
export(gof_censored)
export(pvalue_distribution_free)
export(pvalue_parametric_bootstrap)
export(stat_composite_mle)
export(stat_direct_censored)
export(stat_edf_censored)
export(transform_malmquist)
export(transform_ms)
