% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/transform_ms.R
\name{transform_ms}
\alias{transform_ms}
\title{Michael & Schucany (1979) Transformation}
\usage{
transform_ms(u_cens, n)
}
\arguments{
\item{u_cens}{Numeric vector of order statistics u_1:n < ... < u_r:n in (0, 1).}

\item{n}{Total sample size (n >= length(u_cens)).}
}
\value{
Numeric vector of length r representing the transformed complete sample Z_1:r < ... < Z_r:r.
}
\description{
Transforms an r-out-of-n Type-II right-censored uniform sample into a complete sample of size r.
}
\examples{
u <- c(0.03, 0.06, 0.10, 0.11, 0.13)
transform_ms(u, n = 10)
}
